@@ -18,11 +18,7 @@ use std::sync::{Arc, RwLock};
 mod addressing;
 mod database;
 mod filesystem;
-mod hash;
-mod jobs;
-mod models;
 mod routes;
-mod schema;
 mod util;
 
 const VERSION: &str = env!("CARGO_PKG_VERSION");
@@ -53,6 +49,11 @@ fn main() -> Result<()> {
                 .long("no-browser")
                 .help("Do not open web browser with the UI."),
         )
+        .arg(
+            Arg::with_name("NO_UI")
+                .long("no-ui")
+                .help("Do not serve the web UI."),
+        )
         .arg(
             Arg::with_name("NO_INITIAL_UPDATE")
                 .long("no-initial-update")
@@ -75,7 +76,7 @@ fn main() -> Result<()> {
     info!("Starting UpEnd {}...", VERSION);
     let sys = actix::System::new("upend");
 
-    let job_container = Arc::new(RwLock::new(jobs::JobContainer::default()));
+    let job_container = Arc::new(RwLock::new(util::jobs::JobContainer::default()));
 
     let vault_path = PathBuf::from(matches.value_of("DIRECTORY").unwrap());
 
@@ -103,8 +104,13 @@ fn main() -> Result<()> {
     };
 
     // Start HTTP server
+    let ui_path = env::current_exe().unwrap().parent().unwrap().join("webui");
+    if !ui_path.exists() {
+        warn!("No Web UI directory present ({:?}), disabling...", ui_path);
+    }
+    let ui_enabled = ui_path.exists() && !matches.is_present("NO_UI");
     HttpServer::new(move || {
-        App::new()
+        let app = App::new()
             .data(state.clone())
             .wrap(middleware::Logger::default().exclude("/api/jobs"))
             .service(routes::get_raw)
@@ -117,14 +123,13 @@ fn main() -> Result<()> {
             .service(routes::latest_files)
             .service(routes::get_file)
             .service(routes::get_jobs)
-            .service(routes::get_info)
-            .service(
-                actix_files::Files::new(
-                    "/",
-                    env::current_exe().unwrap().parent().unwrap().join("webui"),
-                )
-                .index_file("index.html"),
-            )
+            .service(routes::get_info);
+
+        if ui_enabled {
+            app.service(actix_files::Files::new("/", &ui_path).index_file("index.html"))
+        } else {
+            app
+        }
     })
     .bind(&bind)?
     .run();
@@ -134,7 +139,7 @@ fn main() -> Result<()> {
         actix::spawn(filesystem::rescan_vault(db_pool, vault_path, job_container));
     }
 
-    if !matches.is_present("NO_BROWSER") {
+    if !matches.is_present("NO_BROWSER") && ui_enabled {
         let ui_result = webbrowser::open(&format!("http://localhost:{}", bind.port()));
         if ui_result.is_err() {
             warn!("Could not open UI in browser!");
