@@ -1,17 +1,18 @@
-use crate::addressing::Address;
+use crate::addressing::{Address, Addressable};
+use crate::database::entry::{Entry, InEntry};
+use crate::database::hierarchies::{list_node, UPath};
+use crate::database::lang::Query;
 use crate::database::{
-    get_latest_files, insert_entry, query, remove_object, retrieve_file, retrieve_object,
-    Addressable, DbPool, Entry, InEntry, Query,
+    get_latest_files, insert_entry, query, remove_object, retrieve_file, retrieve_object, DbPool,
 };
-use crate::filesystem::{list_directory, UPath};
-use crate::hash::{decode, encode};
-use crate::jobs::JobContainer;
+use crate::util::hash::{decode, encode};
+use crate::util::jobs::JobContainer;
 use actix_files::NamedFile;
 use actix_web::error::{ErrorBadRequest, ErrorInternalServerError, ErrorNotFound};
 use actix_web::{delete, error, get, post, put, web, Error, HttpResponse};
 use anyhow::Result;
 use futures_util::StreamExt;
-use log::debug;
+use log::{debug, trace};
 use serde::Deserialize;
 use serde_json::json;
 use std::collections::HashMap;
@@ -172,7 +173,8 @@ pub async fn list_hier(
 ) -> Result<HttpResponse, Error> {
     let connection = state.db_pool.get().map_err(ErrorInternalServerError)?;
     let upath: UPath = path.into_inner().parse().map_err(ErrorBadRequest)?;
-    let entries: Vec<Entry> = list_directory(&connection, &upath)
+    trace!("Listing path \"{}\"", upath);
+    let entries: Vec<Entry> = list_node(&connection, &upath)
         .await
         .map_err(ErrorNotFound)?; // todo: 500 if actual error occurs
 
